%Davide Gironi, 2013
%http://davidegironi.blogspot.it/
%
%this helper tries to correlate pcs/283ml to mg/m^3

ratio = [   0, 0.2, 0.4, 0.6, 0.8, 1.0,  1.2,  1.4]';

%calculate particles pcs/283ml for the given ratio
concentration_pcs283ml = 0.02791 * ratio.^2 + 614.1 * ratio + 4.926;

%calculate particles mg/m^3 for the given ratio
concentration_mgm3 = 0.001915 * ratio.^2 + 0.09522 * ratio - 0.04884;

%particles per 0.01 cubic feet to microgram per cubic meter concentration conversion
%Assumptions
% all particles are spherical, with a density of 1.65E12 ug/m3 (Tittarelli, T. et al., "Estimation of particle mass concentration in ambient air using a particle counter")
% the radius of a particle in the PM2.5 channel is 0.44 um
% 0.01 ft^3 can be converted to m^3 by multiplying by 3531.5
%With the radius fixed, it is possible to derive the volume and multiply by the particle density
% mass of a particle in the PM2.5 channel is 5.89E-7 ug
% (4/3)*pi*(0.44^3)*1.65*10^-12 = 5.89*10^-7
%Finally, the conversion equation is:
%PM[ug/m^3] = particles(particles per 0.01 ft^3) * 3531.5 * particle_mass
%so for PM2.5 -> 3531.5 * particle_mass = 0.002080
pm1_mass = 0.28; %um ref. can not find refereces for this, i simply suppose this by the below reference
pm25_mass = 0.44; %um ref. Lee, J. et al., "Seasonal variations of particle size distributions of PAHs at Seoul, South Korea"
pm10_mass = 2.60; %um ref. Lee, J. et al., "Seasonal variations of particle size distributions of PAHs at Seoul, South Korea"
pm1_pcs283ml_to_mgm3 = (4/3)*pi*(pm1_mass^3)*1.65*10^-6 * 3521.5
concentration_pcs283ml = concentration_pcs283ml * pm1_pcs283ml_to_mgm3;

hold on
plot( ratio, concentration_pcs283ml, 'b' );
plot( ratio, concentration_mgm3, 'r' );
hold off
